Class: Aws::ApiGatewayV2::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ApiGatewayV2::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-apigatewayv2/client.rb,
sig/client.rbs
Overview
An API client for ApiGatewayV2. To construct a client, you need to configure a :region and :credentials.
client = Aws::ApiGatewayV2::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateApiMappingResponseSuccess, _CreateApiResponseSuccess, _CreateAuthorizerResponseSuccess, _CreateDeploymentResponseSuccess, _CreateDomainNameResponseSuccess, _CreateIntegrationResponseResponseSuccess, _CreateIntegrationResponseSuccess, _CreateModelResponseSuccess, _CreatePortalProductResponseSuccess, _CreatePortalResponseSuccess, _CreateProductPageResponseSuccess, _CreateProductRestEndpointPageResponseSuccess, _CreateRouteResponseResponseSuccess, _CreateRouteResponseSuccess, _CreateRoutingRuleResponseSuccess, _CreateStageResponseSuccess, _CreateVpcLinkResponseSuccess, _DeleteVpcLinkResponseSuccess, _ExportApiResponseSuccess, _GetApiMappingResponseSuccess, _GetApiMappingsResponseSuccess, _GetApiResponseSuccess, _GetApisResponseSuccess, _GetAuthorizerResponseSuccess, _GetAuthorizersResponseSuccess, _GetDeploymentResponseSuccess, _GetDeploymentsResponseSuccess, _GetDomainNameResponseSuccess, _GetDomainNamesResponseSuccess, _GetIntegrationResponseResponseSuccess, _GetIntegrationResponseSuccess, _GetIntegrationResponsesResponseSuccess, _GetIntegrationsResponseSuccess, _GetModelResponseSuccess, _GetModelTemplateResponseSuccess, _GetModelsResponseSuccess, _GetPortalProductResponseSuccess, _GetPortalProductSharingPolicyResponseSuccess, _GetPortalResponseSuccess, _GetProductPageResponseSuccess, _GetProductRestEndpointPageResponseSuccess, _GetRouteResponseResponseSuccess, _GetRouteResponseSuccess, _GetRouteResponsesResponseSuccess, _GetRoutesResponseSuccess, _GetRoutingRuleResponseSuccess, _GetStageResponseSuccess, _GetStagesResponseSuccess, _GetTagsResponseSuccess, _GetVpcLinkResponseSuccess, _GetVpcLinksResponseSuccess, _ImportApiResponseSuccess, _ListPortalProductsResponseSuccess, _ListPortalsResponseSuccess, _ListProductPagesResponseSuccess, _ListProductRestEndpointPagesResponseSuccess, _ListRoutingRulesResponseSuccess, _PreviewPortalResponseSuccess, _PublishPortalResponseSuccess, _PutPortalProductSharingPolicyResponseSuccess, _PutRoutingRuleResponseSuccess, _ReimportApiResponseSuccess, _TagResourceResponseSuccess, _UpdateApiMappingResponseSuccess, _UpdateApiResponseSuccess, _UpdateAuthorizerResponseSuccess, _UpdateDeploymentResponseSuccess, _UpdateDomainNameResponseSuccess, _UpdateIntegrationResponseResponseSuccess, _UpdateIntegrationResponseSuccess, _UpdateModelResponseSuccess, _UpdatePortalProductResponseSuccess, _UpdatePortalResponseSuccess, _UpdateProductPageResponseSuccess, _UpdateProductRestEndpointPageResponseSuccess, _UpdateRouteResponseResponseSuccess, _UpdateRouteResponseSuccess, _UpdateStageResponseSuccess, _UpdateVpcLinkResponseSuccess
Constant Summary collapse
- Params =
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_api(params = {}) ⇒ Types::CreateApiResponse
Creates an Api resource.
-
#create_api_mapping(params = {}) ⇒ Types::CreateApiMappingResponse
Creates an API mapping.
-
#create_authorizer(params = {}) ⇒ Types::CreateAuthorizerResponse
Creates an Authorizer for an API.
-
#create_deployment(params = {}) ⇒ Types::CreateDeploymentResponse
Creates a Deployment for an API.
-
#create_domain_name(params = {}) ⇒ Types::CreateDomainNameResponse
Creates a domain name.
-
#create_integration(params = {}) ⇒ Types::CreateIntegrationResult
Creates an Integration.
-
#create_integration_response(params = {}) ⇒ Types::CreateIntegrationResponseResponse
Creates an IntegrationResponses.
-
#create_model(params = {}) ⇒ Types::CreateModelResponse
Creates a Model for an API.
-
#create_portal(params = {}) ⇒ Types::CreatePortalResponse
Creates a portal.
-
#create_portal_product(params = {}) ⇒ Types::CreatePortalProductResponse
Creates a new portal product.
-
#create_product_page(params = {}) ⇒ Types::CreateProductPageResponse
Creates a new product page for a portal product.
-
#create_product_rest_endpoint_page(params = {}) ⇒ Types::CreateProductRestEndpointPageResponse
Creates a product REST endpoint page for a portal product.
-
#create_route(params = {}) ⇒ Types::CreateRouteResult
Creates a Route for an API.
-
#create_route_response(params = {}) ⇒ Types::CreateRouteResponseResponse
Creates a RouteResponse for a Route.
-
#create_routing_rule(params = {}) ⇒ Types::CreateRoutingRuleResponse
Create a routing rule.
-
#create_stage(params = {}) ⇒ Types::CreateStageResponse
Creates a Stage for an API.
-
#create_vpc_link(params = {}) ⇒ Types::CreateVpcLinkResponse
Creates a VPC link.
-
#delete_access_log_settings(params = {}) ⇒ Struct
Deletes the AccessLogSettings for a Stage.
-
#delete_api(params = {}) ⇒ Struct
Deletes an Api resource.
-
#delete_api_mapping(params = {}) ⇒ Struct
Deletes an API mapping.
-
#delete_authorizer(params = {}) ⇒ Struct
Deletes an Authorizer.
-
#delete_cors_configuration(params = {}) ⇒ Struct
Deletes a CORS configuration.
-
#delete_deployment(params = {}) ⇒ Struct
Deletes a Deployment.
-
#delete_domain_name(params = {}) ⇒ Struct
Deletes a domain name.
-
#delete_integration(params = {}) ⇒ Struct
Deletes an Integration.
-
#delete_integration_response(params = {}) ⇒ Struct
Deletes an IntegrationResponses.
-
#delete_model(params = {}) ⇒ Struct
Deletes a Model.
-
#delete_portal(params = {}) ⇒ Struct
Deletes a portal.
-
#delete_portal_product(params = {}) ⇒ Struct
Deletes a portal product.
-
#delete_portal_product_sharing_policy(params = {}) ⇒ Struct
Deletes the sharing policy for a portal product.
-
#delete_product_page(params = {}) ⇒ Struct
Deletes a product page of a portal product.
-
#delete_product_rest_endpoint_page(params = {}) ⇒ Struct
Deletes a product REST endpoint page.
-
#delete_route(params = {}) ⇒ Struct
Deletes a Route.
-
#delete_route_request_parameter(params = {}) ⇒ Struct
Deletes a route request parameter.
-
#delete_route_response(params = {}) ⇒ Struct
Deletes a RouteResponse.
-
#delete_route_settings(params = {}) ⇒ Struct
Deletes the RouteSettings for a stage.
-
#delete_routing_rule(params = {}) ⇒ Struct
Deletes a routing rule.
-
#delete_stage(params = {}) ⇒ Struct
Deletes a Stage.
-
#delete_vpc_link(params = {}) ⇒ Struct
Deletes a VPC link.
-
#disable_portal(params = {}) ⇒ Struct
Deletes the publication of a portal portal.
-
#export_api(params = {}) ⇒ Types::ExportApiResponse
Exports a definition of an API in a particular output format and specification.
-
#get_api(params = {}) ⇒ Types::GetApiResponse
Gets an Api resource.
-
#get_api_mapping(params = {}) ⇒ Types::GetApiMappingResponse
Gets an API mapping.
-
#get_api_mappings(params = {}) ⇒ Types::GetApiMappingsResponse
Gets API mappings.
-
#get_apis(params = {}) ⇒ Types::GetApisResponse
Gets a collection of Api resources.
-
#get_authorizer(params = {}) ⇒ Types::GetAuthorizerResponse
Gets an Authorizer.
-
#get_authorizers(params = {}) ⇒ Types::GetAuthorizersResponse
Gets the Authorizers for an API.
-
#get_deployment(params = {}) ⇒ Types::GetDeploymentResponse
Gets a Deployment.
-
#get_deployments(params = {}) ⇒ Types::GetDeploymentsResponse
Gets the Deployments for an API.
-
#get_domain_name(params = {}) ⇒ Types::GetDomainNameResponse
Gets a domain name.
-
#get_domain_names(params = {}) ⇒ Types::GetDomainNamesResponse
Gets the domain names for an Amazon Web Services account.
-
#get_integration(params = {}) ⇒ Types::GetIntegrationResult
Gets an Integration.
-
#get_integration_response(params = {}) ⇒ Types::GetIntegrationResponseResponse
Gets an IntegrationResponses.
-
#get_integration_responses(params = {}) ⇒ Types::GetIntegrationResponsesResponse
Gets the IntegrationResponses for an Integration.
-
#get_integrations(params = {}) ⇒ Types::GetIntegrationsResponse
Gets the Integrations for an API.
-
#get_model(params = {}) ⇒ Types::GetModelResponse
Gets a Model.
-
#get_model_template(params = {}) ⇒ Types::GetModelTemplateResponse
Gets a model template.
-
#get_models(params = {}) ⇒ Types::GetModelsResponse
Gets the Models for an API.
-
#get_portal(params = {}) ⇒ Types::GetPortalResponse
Gets a portal.
-
#get_portal_product(params = {}) ⇒ Types::GetPortalProductResponse
Gets a portal product.
-
#get_portal_product_sharing_policy(params = {}) ⇒ Types::GetPortalProductSharingPolicyResponse
Gets the sharing policy for a portal product.
-
#get_product_page(params = {}) ⇒ Types::GetProductPageResponse
Gets a product page of a portal product.
-
#get_product_rest_endpoint_page(params = {}) ⇒ Types::GetProductRestEndpointPageResponse
Gets a product REST endpoint page.
-
#get_route(params = {}) ⇒ Types::GetRouteResult
Gets a Route.
-
#get_route_response(params = {}) ⇒ Types::GetRouteResponseResponse
Gets a RouteResponse.
-
#get_route_responses(params = {}) ⇒ Types::GetRouteResponsesResponse
Gets the RouteResponses for a Route.
-
#get_routes(params = {}) ⇒ Types::GetRoutesResponse
Gets the Routes for an API.
-
#get_routing_rule(params = {}) ⇒ Types::GetRoutingRuleResponse
Gets a routing rule.
-
#get_stage(params = {}) ⇒ Types::GetStageResponse
Gets a Stage.
-
#get_stages(params = {}) ⇒ Types::GetStagesResponse
Gets the Stages for an API.
-
#get_tags(params = {}) ⇒ Types::GetTagsResponse
Gets a collection of Tag resources.
-
#get_vpc_link(params = {}) ⇒ Types::GetVpcLinkResponse
Gets a VPC link.
-
#get_vpc_links(params = {}) ⇒ Types::GetVpcLinksResponse
Gets a collection of VPC links.
-
#import_api(params = {}) ⇒ Types::ImportApiResponse
Imports an API.
-
#list_portal_products(params = {}) ⇒ Types::ListPortalProductsResponse
Lists portal products.
-
#list_portals(params = {}) ⇒ Types::ListPortalsResponse
Lists portals.
-
#list_product_pages(params = {}) ⇒ Types::ListProductPagesResponse
Lists the product pages for a portal product.
-
#list_product_rest_endpoint_pages(params = {}) ⇒ Types::ListProductRestEndpointPagesResponse
Lists the product REST endpoint pages of a portal product.
-
#list_routing_rules(params = {}) ⇒ Types::ListRoutingRulesResponse
Lists routing rules.
-
#preview_portal(params = {}) ⇒ Struct
Creates a portal preview.
-
#publish_portal(params = {}) ⇒ Struct
Publishes a portal.
-
#put_portal_product_sharing_policy(params = {}) ⇒ Struct
Updates the sharing policy for a portal product.
-
#put_routing_rule(params = {}) ⇒ Types::PutRoutingRuleResponse
Replaces an existing routing rule.
-
#reimport_api(params = {}) ⇒ Types::ReimportApiResponse
Puts an Api resource.
-
#reset_authorizers_cache(params = {}) ⇒ Struct
Resets all authorizer cache entries for the specified stage.
-
#tag_resource(params = {}) ⇒ Struct
Creates a new Tag resource to represent a tag.
-
#untag_resource(params = {}) ⇒ Struct
Deletes a Tag.
-
#update_api(params = {}) ⇒ Types::UpdateApiResponse
Updates an Api resource.
-
#update_api_mapping(params = {}) ⇒ Types::UpdateApiMappingResponse
The API mapping.
-
#update_authorizer(params = {}) ⇒ Types::UpdateAuthorizerResponse
Updates an Authorizer.
-
#update_deployment(params = {}) ⇒ Types::UpdateDeploymentResponse
Updates a Deployment.
-
#update_domain_name(params = {}) ⇒ Types::UpdateDomainNameResponse
Updates a domain name.
-
#update_integration(params = {}) ⇒ Types::UpdateIntegrationResult
Updates an Integration.
-
#update_integration_response(params = {}) ⇒ Types::UpdateIntegrationResponseResponse
Updates an IntegrationResponses.
-
#update_model(params = {}) ⇒ Types::UpdateModelResponse
Updates a Model.
-
#update_portal(params = {}) ⇒ Types::UpdatePortalResponse
Updates a portal.
-
#update_portal_product(params = {}) ⇒ Types::UpdatePortalProductResponse
Updates the portal product.
-
#update_product_page(params = {}) ⇒ Types::UpdateProductPageResponse
Updates a product page of a portal product.
-
#update_product_rest_endpoint_page(params = {}) ⇒ Types::UpdateProductRestEndpointPageResponse
Updates a product REST endpoint page.
-
#update_route(params = {}) ⇒ Types::UpdateRouteResult
Updates a Route.
-
#update_route_response(params = {}) ⇒ Types::UpdateRouteResponseResponse
Updates a RouteResponse.
-
#update_stage(params = {}) ⇒ Types::UpdateStageResponse
Updates a Stage.
-
#update_vpc_link(params = {}) ⇒ Types::UpdateVpcLinkResponse
Updates a VPC link.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-apigatewayv2/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6151 6152 6153 |
# File 'lib/aws-sdk-apigatewayv2/client.rb', line 6151 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6154 6155 6156 |
# File 'lib/aws-sdk-apigatewayv2/client.rb', line 6154 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6124 6125 6126 6127 6128 6129 6130 6131 6132 6133 6134 6135 6136 6137 6138 6139 6140 |
# File 'lib/aws-sdk-apigatewayv2/client.rb', line 6124 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ApiGatewayV2') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-apigatewayv2' context[:gem_version] = '1.98.0' Seahorse::Client::Request.new(handlers, context) end |
#create_api(params = {}) ⇒ Types::CreateApiResponse
Creates an Api resource.
102 |
# File 'sig/client.rbs', line 102
def create_api: (
|
#create_api_mapping(params = {}) ⇒ Types::CreateApiMappingResponse
Creates an API mapping.
128 |
# File 'sig/client.rbs', line 128
def create_api_mapping: (
|
#create_authorizer(params = {}) ⇒ Types::CreateAuthorizerResponse
Creates an Authorizer for an API.
151 |
# File 'sig/client.rbs', line 151
def create_authorizer: (
|
#create_deployment(params = {}) ⇒ Types::CreateDeploymentResponse
Creates a Deployment for an API.
179 |
# File 'sig/client.rbs', line 179
def create_deployment: (
|
#create_domain_name(params = {}) ⇒ Types::CreateDomainNameResponse
Creates a domain name.
197 |
# File 'sig/client.rbs', line 197
def create_domain_name: (
|
#create_integration(params = {}) ⇒ Types::CreateIntegrationResult
Creates an Integration.
235 |
# File 'sig/client.rbs', line 235
def create_integration: (
|
#create_integration_response(params = {}) ⇒ Types::CreateIntegrationResponseResponse
Creates an IntegrationResponses.
269 |
# File 'sig/client.rbs', line 269
def create_integration_response: (
|
#create_model(params = {}) ⇒ Types::CreateModelResponse
Creates a Model for an API.
289 |
# File 'sig/client.rbs', line 289
def create_model: (
|
#create_portal(params = {}) ⇒ Types::CreatePortalResponse
Creates a portal.
315 |
# File 'sig/client.rbs', line 315
def create_portal: (
|
#create_portal_product(params = {}) ⇒ Types::CreatePortalProductResponse
Creates a new portal product.
337 |
# File 'sig/client.rbs', line 337
def create_portal_product: (
|
#create_product_page(params = {}) ⇒ Types::CreateProductPageResponse
Creates a new product page for a portal product.
352 |
# File 'sig/client.rbs', line 352
def create_product_page: (
|
#create_product_rest_endpoint_page(params = {}) ⇒ Types::CreateProductRestEndpointPageResponse
Creates a product REST endpoint page for a portal product.
373 |
# File 'sig/client.rbs', line 373
def create_product_rest_endpoint_page: (
|
#create_route(params = {}) ⇒ Types::CreateRouteResult
Creates a Route for an API.
405 |
# File 'sig/client.rbs', line 405
def create_route: (
|
#create_route_response(params = {}) ⇒ Types::CreateRouteResponseResponse
Creates a RouteResponse for a Route.
432 |
# File 'sig/client.rbs', line 432
def create_route_response: (
|
#create_routing_rule(params = {}) ⇒ Types::CreateRoutingRuleResponse
Create a routing rule.
453 |
# File 'sig/client.rbs', line 453
def create_routing_rule: (
|
#create_stage(params = {}) ⇒ Types::CreateStageResponse
Creates a Stage for an API.
490 |
# File 'sig/client.rbs', line 490
def create_stage: (
|
#create_vpc_link(params = {}) ⇒ Types::CreateVpcLinkResponse
Creates a VPC link.
533 |
# File 'sig/client.rbs', line 533
def create_vpc_link: (
|
#delete_access_log_settings(params = {}) ⇒ Struct
Deletes the AccessLogSettings for a Stage. To disable access logging for a Stage, delete its AccessLogSettings.
542 |
# File 'sig/client.rbs', line 542
def delete_access_log_settings: (
|
#delete_api(params = {}) ⇒ Struct
Deletes an Api resource.
549 |
# File 'sig/client.rbs', line 549
def delete_api: (
|
#delete_api_mapping(params = {}) ⇒ Struct
Deletes an API mapping.
555 |
# File 'sig/client.rbs', line 555
def delete_api_mapping: (
|
#delete_authorizer(params = {}) ⇒ Struct
Deletes an Authorizer.
562 |
# File 'sig/client.rbs', line 562
def delete_authorizer: (
|
#delete_cors_configuration(params = {}) ⇒ Struct
Deletes a CORS configuration.
569 |
# File 'sig/client.rbs', line 569
def delete_cors_configuration: (
|
#delete_deployment(params = {}) ⇒ Struct
Deletes a Deployment.
575 |
# File 'sig/client.rbs', line 575
def delete_deployment: (
|
#delete_domain_name(params = {}) ⇒ Struct
Deletes a domain name.
582 |
# File 'sig/client.rbs', line 582
def delete_domain_name: (
|
#delete_integration(params = {}) ⇒ Struct
Deletes an Integration.
588 |
# File 'sig/client.rbs', line 588
def delete_integration: (
|
#delete_integration_response(params = {}) ⇒ Struct
Deletes an IntegrationResponses.
595 |
# File 'sig/client.rbs', line 595
def delete_integration_response: (
|
#delete_model(params = {}) ⇒ Struct
Deletes a Model.
603 |
# File 'sig/client.rbs', line 603
def delete_model: (
|
#delete_portal(params = {}) ⇒ Struct
Deletes a portal.
610 |
# File 'sig/client.rbs', line 610
def delete_portal: (
|
#delete_portal_product(params = {}) ⇒ Struct
Deletes a portal product.
616 |
# File 'sig/client.rbs', line 616
def delete_portal_product: (
|
#delete_portal_product_sharing_policy(params = {}) ⇒ Struct
Deletes the sharing policy for a portal product.
622 |
# File 'sig/client.rbs', line 622
def delete_portal_product_sharing_policy: (
|
#delete_product_page(params = {}) ⇒ Struct
Deletes a product page of a portal product.
628 |
# File 'sig/client.rbs', line 628
def delete_product_page: (
|
#delete_product_rest_endpoint_page(params = {}) ⇒ Struct
Deletes a product REST endpoint page.
635 |
# File 'sig/client.rbs', line 635
def delete_product_rest_endpoint_page: (
|
#delete_route(params = {}) ⇒ Struct
Deletes a Route.
642 |
# File 'sig/client.rbs', line 642
def delete_route: (
|
#delete_route_request_parameter(params = {}) ⇒ Struct
Deletes a route request parameter. Supported only for WebSocket APIs.
649 |
# File 'sig/client.rbs', line 649
def delete_route_request_parameter: (
|
#delete_route_response(params = {}) ⇒ Struct
Deletes a RouteResponse.
657 |
# File 'sig/client.rbs', line 657
def delete_route_response: (
|
#delete_route_settings(params = {}) ⇒ Struct
Deletes the RouteSettings for a stage.
665 |
# File 'sig/client.rbs', line 665
def delete_route_settings: (
|
#delete_routing_rule(params = {}) ⇒ Struct
Deletes a routing rule.
673 |
# File 'sig/client.rbs', line 673
def delete_routing_rule: (
|
#delete_stage(params = {}) ⇒ Struct
Deletes a Stage.
681 |
# File 'sig/client.rbs', line 681
def delete_stage: (
|
#delete_vpc_link(params = {}) ⇒ Struct
Deletes a VPC link.
691 |
# File 'sig/client.rbs', line 691
def delete_vpc_link: (
|
#disable_portal(params = {}) ⇒ Struct
Deletes the publication of a portal portal.
712 |
# File 'sig/client.rbs', line 712
def disable_portal: (
|
#export_api(params = {}) ⇒ Types::ExportApiResponse
Exports a definition of an API in a particular output format and specification.
701 |
# File 'sig/client.rbs', line 701
def export_api: (
|
#get_api(params = {}) ⇒ Types::GetApiResponse
Gets an Api resource.
745 |
# File 'sig/client.rbs', line 745
def get_api: (
|
#get_api_mapping(params = {}) ⇒ Types::GetApiMappingResponse
Gets an API mapping.
758 |
# File 'sig/client.rbs', line 758
def get_api_mapping: (
|
#get_api_mappings(params = {}) ⇒ Types::GetApiMappingsResponse
Gets API mappings.
770 |
# File 'sig/client.rbs', line 770
def get_api_mappings: (
|
#get_apis(params = {}) ⇒ Types::GetApisResponse
Gets a collection of Api resources.
783 |
# File 'sig/client.rbs', line 783
def get_apis: (
|
#get_authorizer(params = {}) ⇒ Types::GetAuthorizerResponse
Gets an Authorizer.
804 |
# File 'sig/client.rbs', line 804
def get_authorizer: (
|
#get_authorizers(params = {}) ⇒ Types::GetAuthorizersResponse
Gets the Authorizers for an API.
816 |
# File 'sig/client.rbs', line 816
def get_authorizers: (
|
#get_deployment(params = {}) ⇒ Types::GetDeploymentResponse
Gets a Deployment.
833 |
# File 'sig/client.rbs', line 833
def get_deployment: (
|
#get_deployments(params = {}) ⇒ Types::GetDeploymentsResponse
Gets the Deployments for an API.
845 |
# File 'sig/client.rbs', line 845
def get_deployments: (
|
#get_domain_name(params = {}) ⇒ Types::GetDomainNameResponse
Gets a domain name.
863 |
# File 'sig/client.rbs', line 863
def get_domain_name: (
|
#get_domain_names(params = {}) ⇒ Types::GetDomainNamesResponse
Gets the domain names for an Amazon Web Services account.
874 |
# File 'sig/client.rbs', line 874
def get_domain_names: (
|
#get_integration(params = {}) ⇒ Types::GetIntegrationResult
Gets an Integration.
904 |
# File 'sig/client.rbs', line 904
def get_integration: (
|
#get_integration_response(params = {}) ⇒ Types::GetIntegrationResponseResponse
Gets an IntegrationResponses.
920 |
# File 'sig/client.rbs', line 920
def get_integration_response: (
|
#get_integration_responses(params = {}) ⇒ Types::GetIntegrationResponsesResponse
Gets the IntegrationResponses for an Integration.
933 |
# File 'sig/client.rbs', line 933
def get_integration_responses: (
|
#get_integrations(params = {}) ⇒ Types::GetIntegrationsResponse
Gets the Integrations for an API.
947 |
# File 'sig/client.rbs', line 947
def get_integrations: (
|
#get_model(params = {}) ⇒ Types::GetModelResponse
Gets a Model.
963 |
# File 'sig/client.rbs', line 963
def get_model: (
|
#get_model_template(params = {}) ⇒ Types::GetModelTemplateResponse
Gets a model template.
974 |
# File 'sig/client.rbs', line 974
def get_model_template: (
|
#get_models(params = {}) ⇒ Types::GetModelsResponse
Gets the Models for an API.
986 |
# File 'sig/client.rbs', line 986
def get_models: (
|
#get_portal(params = {}) ⇒ Types::GetPortalResponse
Gets a portal.
1011 |
# File 'sig/client.rbs', line 1011
def get_portal: (
|
#get_portal_product(params = {}) ⇒ Types::GetPortalProductResponse
Gets a portal product.
1027 |
# File 'sig/client.rbs', line 1027
def get_portal_product: (
|
#get_portal_product_sharing_policy(params = {}) ⇒ Types::GetPortalProductSharingPolicyResponse
Gets the sharing policy for a portal product.
1039 |
# File 'sig/client.rbs', line 1039
def get_portal_product_sharing_policy: (
|
#get_product_page(params = {}) ⇒ Types::GetProductPageResponse
Gets a product page of a portal product.
1052 |
# File 'sig/client.rbs', line 1052
def get_product_page: (
|
#get_product_rest_endpoint_page(params = {}) ⇒ Types::GetProductRestEndpointPageResponse
Gets a product REST endpoint page.
1072 |
# File 'sig/client.rbs', line 1072
def get_product_rest_endpoint_page: (
|
#get_route(params = {}) ⇒ Types::GetRouteResult
Gets a Route.
1097 |
# File 'sig/client.rbs', line 1097
def get_route: (
|
#get_route_response(params = {}) ⇒ Types::GetRouteResponseResponse
Gets a RouteResponse.
1112 |
# File 'sig/client.rbs', line 1112
def get_route_response: (
|
#get_route_responses(params = {}) ⇒ Types::GetRouteResponsesResponse
Gets the RouteResponses for a Route.
1125 |
# File 'sig/client.rbs', line 1125
def get_route_responses: (
|
#get_routes(params = {}) ⇒ Types::GetRoutesResponse
Gets the Routes for an API.
1139 |
# File 'sig/client.rbs', line 1139
def get_routes: (
|
#get_routing_rule(params = {}) ⇒ Types::GetRoutingRuleResponse
Gets a routing rule.
1155 |
# File 'sig/client.rbs', line 1155
def get_routing_rule: (
|
#get_stage(params = {}) ⇒ Types::GetStageResponse
Gets a Stage.
1180 |
# File 'sig/client.rbs', line 1180
def get_stage: (
|
#get_stages(params = {}) ⇒ Types::GetStagesResponse
Gets the Stages for an API.
1192 |
# File 'sig/client.rbs', line 1192
def get_stages: (
|
#get_tags(params = {}) ⇒ Types::GetTagsResponse
Gets a collection of Tag resources.
1204 |
# File 'sig/client.rbs', line 1204
def get_tags: (
|
#get_vpc_link(params = {}) ⇒ Types::GetVpcLinkResponse
Gets a VPC link.
1222 |
# File 'sig/client.rbs', line 1222
def get_vpc_link: (
|
#get_vpc_links(params = {}) ⇒ Types::GetVpcLinksResponse
Gets a collection of VPC links.
1233 |
# File 'sig/client.rbs', line 1233
def get_vpc_links: (
|
#import_api(params = {}) ⇒ Types::ImportApiResponse
Imports an API.
1260 |
# File 'sig/client.rbs', line 1260
def import_api: (
|
#list_portal_products(params = {}) ⇒ Types::ListPortalProductsResponse
Lists portal products.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1273 |
# File 'sig/client.rbs', line 1273
def list_portal_products: (
|
#list_portals(params = {}) ⇒ Types::ListPortalsResponse
Lists portals.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1286 |
# File 'sig/client.rbs', line 1286
def list_portals: (
|
#list_product_pages(params = {}) ⇒ Types::ListProductPagesResponse
Lists the product pages for a portal product.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1298 |
# File 'sig/client.rbs', line 1298
def list_product_pages: (
|
#list_product_rest_endpoint_pages(params = {}) ⇒ Types::ListProductRestEndpointPagesResponse
Lists the product REST endpoint pages of a portal product.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1312 |
# File 'sig/client.rbs', line 1312
def list_product_rest_endpoint_pages: (
|
#list_routing_rules(params = {}) ⇒ Types::ListRoutingRulesResponse
Lists routing rules.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1326 |
# File 'sig/client.rbs', line 1326
def list_routing_rules: (
|
#preview_portal(params = {}) ⇒ Struct
Creates a portal preview.
1338 |
# File 'sig/client.rbs', line 1338
def preview_portal: (
|
#publish_portal(params = {}) ⇒ Struct
Publishes a portal.
1347 |
# File 'sig/client.rbs', line 1347
def publish_portal: (
|
#put_portal_product_sharing_policy(params = {}) ⇒ Struct
Updates the sharing policy for a portal product.
1357 |
# File 'sig/client.rbs', line 1357
def put_portal_product_sharing_policy: (
|
#put_routing_rule(params = {}) ⇒ Types::PutRoutingRuleResponse
Replaces an existing routing rule. When you replace an existing routing rule, the RoutingRuleId isn't changed.
1372 |
# File 'sig/client.rbs', line 1372
def put_routing_rule: (
|
#reimport_api(params = {}) ⇒ Types::ReimportApiResponse
Puts an Api resource.
1413 |
# File 'sig/client.rbs', line 1413
def reimport_api: (
|
#reset_authorizers_cache(params = {}) ⇒ Struct
Resets all authorizer cache entries for the specified stage. Supported only for HTTP API Lambda authorizers.
718 |
# File 'sig/client.rbs', line 718
def reset_authorizers_cache: (
|
#tag_resource(params = {}) ⇒ Struct
Creates a new Tag resource to represent a tag.
1425 |
# File 'sig/client.rbs', line 1425
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Deletes a Tag.
1432 |
# File 'sig/client.rbs', line 1432
def untag_resource: (
|
#update_api(params = {}) ⇒ Types::UpdateApiResponse
Updates an Api resource.
1459 |
# File 'sig/client.rbs', line 1459
def update_api: (
|
#update_api_mapping(params = {}) ⇒ Types::UpdateApiMappingResponse
The API mapping.
1484 |
# File 'sig/client.rbs', line 1484
def update_api_mapping: (
|
#update_authorizer(params = {}) ⇒ Types::UpdateAuthorizerResponse
Updates an Authorizer.
1508 |
# File 'sig/client.rbs', line 1508
def update_authorizer: (
|
#update_deployment(params = {}) ⇒ Types::UpdateDeploymentResponse
Updates a Deployment.
1537 |
# File 'sig/client.rbs', line 1537
def update_deployment: (
|
#update_domain_name(params = {}) ⇒ Types::UpdateDomainNameResponse
Updates a domain name.
1555 |
# File 'sig/client.rbs', line 1555
def update_domain_name: (
|
#update_integration(params = {}) ⇒ Types::UpdateIntegrationResult
Updates an Integration.
1592 |
# File 'sig/client.rbs', line 1592
def update_integration: (
|
#update_integration_response(params = {}) ⇒ Types::UpdateIntegrationResponseResponse
Updates an IntegrationResponses.
1627 |
# File 'sig/client.rbs', line 1627
def update_integration_response: (
|
#update_model(params = {}) ⇒ Types::UpdateModelResponse
Updates a Model.
1648 |
# File 'sig/client.rbs', line 1648
def update_model: (
|
#update_portal(params = {}) ⇒ Types::UpdatePortalResponse
Updates a portal.
1676 |
# File 'sig/client.rbs', line 1676
def update_portal: (
|
#update_portal_product(params = {}) ⇒ Types::UpdatePortalProductResponse
Updates the portal product.
1698 |
# File 'sig/client.rbs', line 1698
def update_portal_product: (
|
#update_product_page(params = {}) ⇒ Types::UpdateProductPageResponse
Updates a product page of a portal product.
1723 |
# File 'sig/client.rbs', line 1723
def update_product_page: (
|
#update_product_rest_endpoint_page(params = {}) ⇒ Types::UpdateProductRestEndpointPageResponse
Updates a product REST endpoint page.
1745 |
# File 'sig/client.rbs', line 1745
def update_product_rest_endpoint_page: (
|
#update_route(params = {}) ⇒ Types::UpdateRouteResult
Updates a Route.
1770 |
# File 'sig/client.rbs', line 1770
def update_route: (
|
#update_route_response(params = {}) ⇒ Types::UpdateRouteResponseResponse
Updates a RouteResponse.
1798 |
# File 'sig/client.rbs', line 1798
def update_route_response: (
|
#update_stage(params = {}) ⇒ Types::UpdateStageResponse
Updates a Stage.
1829 |
# File 'sig/client.rbs', line 1829
def update_stage: (
|
#update_vpc_link(params = {}) ⇒ Types::UpdateVpcLinkResponse
Updates a VPC link.
1871 |
# File 'sig/client.rbs', line 1871
def update_vpc_link: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6144 6145 6146 |
# File 'lib/aws-sdk-apigatewayv2/client.rb', line 6144 def waiter_names [] end |