Class: Aws::ApiGatewayV2::Types::CreatePortalRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApiGatewayV2::Types::CreatePortalRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-apigatewayv2/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#authorization ⇒ Types::Authorization
Represents an authorization configuration for a portal.
-
#endpoint_configuration ⇒ Types::EndpointConfigurationRequest
Represents an endpoint configuration.
- #included_portal_product_arns ⇒ Array<String>
- #logo_uri ⇒ String
-
#portal_content ⇒ Types::PortalContent
Contains the content that is visible to portal consumers including the themes, display names, and description.
- #rum_app_monitor_name ⇒ String
-
#tags ⇒ Hash<String,String>
Represents a collection of tags associated with the resource.
Instance Attribute Details
#authorization ⇒ Types::Authorization
Represents an authorization configuration for a portal.
2358 2359 2360 2361 2362 2363 2364 2365 2366 2367 2368 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 2358 class CreatePortalRequest < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :logo_uri, :portal_content, :rum_app_monitor_name, :tags) SENSITIVE = [] include Aws::Structure end |
#endpoint_configuration ⇒ Types::EndpointConfigurationRequest
Represents an endpoint configuration.
2358 2359 2360 2361 2362 2363 2364 2365 2366 2367 2368 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 2358 class CreatePortalRequest < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :logo_uri, :portal_content, :rum_app_monitor_name, :tags) SENSITIVE = [] include Aws::Structure end |
#included_portal_product_arns ⇒ Array<String>
2358 2359 2360 2361 2362 2363 2364 2365 2366 2367 2368 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 2358 class CreatePortalRequest < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :logo_uri, :portal_content, :rum_app_monitor_name, :tags) SENSITIVE = [] include Aws::Structure end |
#logo_uri ⇒ String
2358 2359 2360 2361 2362 2363 2364 2365 2366 2367 2368 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 2358 class CreatePortalRequest < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :logo_uri, :portal_content, :rum_app_monitor_name, :tags) SENSITIVE = [] include Aws::Structure end |
#portal_content ⇒ Types::PortalContent
Contains the content that is visible to portal consumers including the themes, display names, and description.
2358 2359 2360 2361 2362 2363 2364 2365 2366 2367 2368 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 2358 class CreatePortalRequest < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :logo_uri, :portal_content, :rum_app_monitor_name, :tags) SENSITIVE = [] include Aws::Structure end |
#rum_app_monitor_name ⇒ String
2358 2359 2360 2361 2362 2363 2364 2365 2366 2367 2368 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 2358 class CreatePortalRequest < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :logo_uri, :portal_content, :rum_app_monitor_name, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Represents a collection of tags associated with the resource.
2358 2359 2360 2361 2362 2363 2364 2365 2366 2367 2368 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 2358 class CreatePortalRequest < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :logo_uri, :portal_content, :rum_app_monitor_name, :tags) SENSITIVE = [] include Aws::Structure end |