Class: Aws::ApiGatewayV2::Types::CreatePortalRequestContent

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-apigatewayv2/types.rb

Overview

Creates a portal.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#authorizationTypes::Authorization

The authentication configuration for the portal.



2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 2404

class CreatePortalRequestContent < Struct.new(
  :authorization,
  :endpoint_configuration,
  :included_portal_product_arns,
  :logo_uri,
  :portal_content,
  :rum_app_monitor_name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_configurationTypes::EndpointConfigurationRequest

The domain configuration for the portal. Use a default domain provided by API Gateway or provide a fully-qualified domain name that you own.



2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 2404

class CreatePortalRequestContent < Struct.new(
  :authorization,
  :endpoint_configuration,
  :included_portal_product_arns,
  :logo_uri,
  :portal_content,
  :rum_app_monitor_name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#included_portal_product_arnsArray<String>

The ARNs of the portal products included in the portal.

Returns:

  • (Array<String>)


2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 2404

class CreatePortalRequestContent < Struct.new(
  :authorization,
  :endpoint_configuration,
  :included_portal_product_arns,
  :logo_uri,
  :portal_content,
  :rum_app_monitor_name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#logo_uriString

The URI for the portal logo image that is displayed in the portal header.

Returns:

  • (String)


2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 2404

class CreatePortalRequestContent < Struct.new(
  :authorization,
  :endpoint_configuration,
  :included_portal_product_arns,
  :logo_uri,
  :portal_content,
  :rum_app_monitor_name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#portal_contentTypes::PortalContent

The content of the portal.



2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 2404

class CreatePortalRequestContent < Struct.new(
  :authorization,
  :endpoint_configuration,
  :included_portal_product_arns,
  :logo_uri,
  :portal_content,
  :rum_app_monitor_name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#rum_app_monitor_nameString

The name of the Amazon CloudWatch RUM app monitor for the portal.

Returns:

  • (String)


2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 2404

class CreatePortalRequestContent < Struct.new(
  :authorization,
  :endpoint_configuration,
  :included_portal_product_arns,
  :logo_uri,
  :portal_content,
  :rum_app_monitor_name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The collection of tags. Each tag element is associated with a given resource.

Returns:

  • (Hash<String,String>)


2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 2404

class CreatePortalRequestContent < Struct.new(
  :authorization,
  :endpoint_configuration,
  :included_portal_product_arns,
  :logo_uri,
  :portal_content,
  :rum_app_monitor_name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end