Class: Aws::ApiGatewayV2::Types::CreateProductRestEndpointPageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApiGatewayV2::Types::CreateProductRestEndpointPageRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-apigatewayv2/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#display_content ⇒ Types::EndpointDisplayContent
Represents the endpoint display content.
- #portal_product_id ⇒ String
-
#rest_endpoint_identifier ⇒ Types::RestEndpointIdentifier
The REST API endpoint identifier.
-
#try_it_state ⇒ String
Represents the try it state for a product REST endpoint page.
Instance Attribute Details
#display_content ⇒ Types::EndpointDisplayContent
Represents the endpoint display content.
2646 2647 2648 2649 2650 2651 2652 2653 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 2646 class CreateProductRestEndpointPageRequest < Struct.new( :display_content, :portal_product_id, :rest_endpoint_identifier, :try_it_state) SENSITIVE = [] include Aws::Structure end |
#portal_product_id ⇒ String
2646 2647 2648 2649 2650 2651 2652 2653 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 2646 class CreateProductRestEndpointPageRequest < Struct.new( :display_content, :portal_product_id, :rest_endpoint_identifier, :try_it_state) SENSITIVE = [] include Aws::Structure end |
#rest_endpoint_identifier ⇒ Types::RestEndpointIdentifier
The REST API endpoint identifier.
2646 2647 2648 2649 2650 2651 2652 2653 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 2646 class CreateProductRestEndpointPageRequest < Struct.new( :display_content, :portal_product_id, :rest_endpoint_identifier, :try_it_state) SENSITIVE = [] include Aws::Structure end |
#try_it_state ⇒ String
Represents the try it state for a product REST endpoint page.
2646 2647 2648 2649 2650 2651 2652 2653 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 2646 class CreateProductRestEndpointPageRequest < Struct.new( :display_content, :portal_product_id, :rest_endpoint_identifier, :try_it_state) SENSITIVE = [] include Aws::Structure end |