Class: Aws::ApiGatewayV2::Types::GetPortalResponseContent

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-apigatewayv2/types.rb

Overview

Gets a portal.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#authorizationTypes::Authorization

The authorization for the portal.



5420
5421
5422
5423
5424
5425
5426
5427
5428
5429
5430
5431
5432
5433
5434
5435
5436
5437
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 5420

class GetPortalResponseContent < Struct.new(
  :authorization,
  :endpoint_configuration,
  :included_portal_product_arns,
  :last_modified,
  :last_published,
  :last_published_description,
  :portal_arn,
  :portal_content,
  :portal_id,
  :preview,
  :publish_status,
  :rum_app_monitor_name,
  :status_exception,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_configurationTypes::EndpointConfigurationResponse

The endpoint configuration.



5420
5421
5422
5423
5424
5425
5426
5427
5428
5429
5430
5431
5432
5433
5434
5435
5436
5437
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 5420

class GetPortalResponseContent < Struct.new(
  :authorization,
  :endpoint_configuration,
  :included_portal_product_arns,
  :last_modified,
  :last_published,
  :last_published_description,
  :portal_arn,
  :portal_content,
  :portal_id,
  :preview,
  :publish_status,
  :rum_app_monitor_name,
  :status_exception,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#included_portal_product_arnsArray<String>

The ARNs of the portal products included in the portal.

Returns:

  • (Array<String>)


5420
5421
5422
5423
5424
5425
5426
5427
5428
5429
5430
5431
5432
5433
5434
5435
5436
5437
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 5420

class GetPortalResponseContent < Struct.new(
  :authorization,
  :endpoint_configuration,
  :included_portal_product_arns,
  :last_modified,
  :last_published,
  :last_published_description,
  :portal_arn,
  :portal_content,
  :portal_id,
  :preview,
  :publish_status,
  :rum_app_monitor_name,
  :status_exception,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#last_modifiedTime

The timestamp when the portal was last modified.

Returns:

  • (Time)


5420
5421
5422
5423
5424
5425
5426
5427
5428
5429
5430
5431
5432
5433
5434
5435
5436
5437
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 5420

class GetPortalResponseContent < Struct.new(
  :authorization,
  :endpoint_configuration,
  :included_portal_product_arns,
  :last_modified,
  :last_published,
  :last_published_description,
  :portal_arn,
  :portal_content,
  :portal_id,
  :preview,
  :publish_status,
  :rum_app_monitor_name,
  :status_exception,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#last_publishedTime

The timestamp when the portal was last published.

Returns:

  • (Time)


5420
5421
5422
5423
5424
5425
5426
5427
5428
5429
5430
5431
5432
5433
5434
5435
5436
5437
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 5420

class GetPortalResponseContent < Struct.new(
  :authorization,
  :endpoint_configuration,
  :included_portal_product_arns,
  :last_modified,
  :last_published,
  :last_published_description,
  :portal_arn,
  :portal_content,
  :portal_id,
  :preview,
  :publish_status,
  :rum_app_monitor_name,
  :status_exception,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#last_published_descriptionString

The publish description used when the portal was last published.

Returns:

  • (String)


5420
5421
5422
5423
5424
5425
5426
5427
5428
5429
5430
5431
5432
5433
5434
5435
5436
5437
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 5420

class GetPortalResponseContent < Struct.new(
  :authorization,
  :endpoint_configuration,
  :included_portal_product_arns,
  :last_modified,
  :last_published,
  :last_published_description,
  :portal_arn,
  :portal_content,
  :portal_id,
  :preview,
  :publish_status,
  :rum_app_monitor_name,
  :status_exception,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#portal_arnString

The ARN of the portal.

Returns:

  • (String)


5420
5421
5422
5423
5424
5425
5426
5427
5428
5429
5430
5431
5432
5433
5434
5435
5436
5437
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 5420

class GetPortalResponseContent < Struct.new(
  :authorization,
  :endpoint_configuration,
  :included_portal_product_arns,
  :last_modified,
  :last_published,
  :last_published_description,
  :portal_arn,
  :portal_content,
  :portal_id,
  :preview,
  :publish_status,
  :rum_app_monitor_name,
  :status_exception,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#portal_contentTypes::PortalContent

Contains the content that is visible to portal consumers including the themes, display names, and description.



5420
5421
5422
5423
5424
5425
5426
5427
5428
5429
5430
5431
5432
5433
5434
5435
5436
5437
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 5420

class GetPortalResponseContent < Struct.new(
  :authorization,
  :endpoint_configuration,
  :included_portal_product_arns,
  :last_modified,
  :last_published,
  :last_published_description,
  :portal_arn,
  :portal_content,
  :portal_id,
  :preview,
  :publish_status,
  :rum_app_monitor_name,
  :status_exception,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#portal_idString

The portal identifier.

Returns:

  • (String)


5420
5421
5422
5423
5424
5425
5426
5427
5428
5429
5430
5431
5432
5433
5434
5435
5436
5437
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 5420

class GetPortalResponseContent < Struct.new(
  :authorization,
  :endpoint_configuration,
  :included_portal_product_arns,
  :last_modified,
  :last_published,
  :last_published_description,
  :portal_arn,
  :portal_content,
  :portal_id,
  :preview,
  :publish_status,
  :rum_app_monitor_name,
  :status_exception,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#previewTypes::Preview

Represents the preview endpoint and the any possible error messages during preview generation.

Returns:



5420
5421
5422
5423
5424
5425
5426
5427
5428
5429
5430
5431
5432
5433
5434
5435
5436
5437
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 5420

class GetPortalResponseContent < Struct.new(
  :authorization,
  :endpoint_configuration,
  :included_portal_product_arns,
  :last_modified,
  :last_published,
  :last_published_description,
  :portal_arn,
  :portal_content,
  :portal_id,
  :preview,
  :publish_status,
  :rum_app_monitor_name,
  :status_exception,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#publish_statusString

The publish status of a portal.

Returns:

  • (String)


5420
5421
5422
5423
5424
5425
5426
5427
5428
5429
5430
5431
5432
5433
5434
5435
5436
5437
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 5420

class GetPortalResponseContent < Struct.new(
  :authorization,
  :endpoint_configuration,
  :included_portal_product_arns,
  :last_modified,
  :last_published,
  :last_published_description,
  :portal_arn,
  :portal_content,
  :portal_id,
  :preview,
  :publish_status,
  :rum_app_monitor_name,
  :status_exception,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#rum_app_monitor_nameString

The CloudWatch RUM app monitor name.

Returns:

  • (String)


5420
5421
5422
5423
5424
5425
5426
5427
5428
5429
5430
5431
5432
5433
5434
5435
5436
5437
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 5420

class GetPortalResponseContent < Struct.new(
  :authorization,
  :endpoint_configuration,
  :included_portal_product_arns,
  :last_modified,
  :last_published,
  :last_published_description,
  :portal_arn,
  :portal_content,
  :portal_id,
  :preview,
  :publish_status,
  :rum_app_monitor_name,
  :status_exception,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#status_exceptionTypes::StatusException

The status exception information.



5420
5421
5422
5423
5424
5425
5426
5427
5428
5429
5430
5431
5432
5433
5434
5435
5436
5437
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 5420

class GetPortalResponseContent < Struct.new(
  :authorization,
  :endpoint_configuration,
  :included_portal_product_arns,
  :last_modified,
  :last_published,
  :last_published_description,
  :portal_arn,
  :portal_content,
  :portal_id,
  :preview,
  :publish_status,
  :rum_app_monitor_name,
  :status_exception,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The collection of tags. Each tag element is associated with a given resource.

Returns:

  • (Hash<String,String>)


5420
5421
5422
5423
5424
5425
5426
5427
5428
5429
5430
5431
5432
5433
5434
5435
5436
5437
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 5420

class GetPortalResponseContent < Struct.new(
  :authorization,
  :endpoint_configuration,
  :included_portal_product_arns,
  :last_modified,
  :last_published,
  :last_published_description,
  :portal_arn,
  :portal_content,
  :portal_id,
  :preview,
  :publish_status,
  :rum_app_monitor_name,
  :status_exception,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end