Class: Aws::ApiGatewayV2::Types::PortalSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-apigatewayv2/types.rb

Overview

Represents a portal summary.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#authorizationTypes::Authorization

The authorization of the portal.

Returns:



7241
7242
7243
7244
7245
7246
7247
7248
7249
7250
7251
7252
7253
7254
7255
7256
7257
7258
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 7241

class PortalSummary < Struct.new(
  :authorization,
  :endpoint_configuration,
  :included_portal_product_arns,
  :last_modified,
  :last_published,
  :last_published_description,
  :portal_arn,
  :portal_content,
  :portal_id,
  :preview,
  :publish_status,
  :rum_app_monitor_name,
  :status_exception,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_configurationTypes::EndpointConfigurationResponse

The endpoint configuration of the portal.

Returns:



7241
7242
7243
7244
7245
7246
7247
7248
7249
7250
7251
7252
7253
7254
7255
7256
7257
7258
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 7241

class PortalSummary < Struct.new(
  :authorization,
  :endpoint_configuration,
  :included_portal_product_arns,
  :last_modified,
  :last_published,
  :last_published_description,
  :portal_arn,
  :portal_content,
  :portal_id,
  :preview,
  :publish_status,
  :rum_app_monitor_name,
  :status_exception,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#included_portal_product_arnsArray<String>

The ARNs of the portal products included in the portal.

Returns:



7241
7242
7243
7244
7245
7246
7247
7248
7249
7250
7251
7252
7253
7254
7255
7256
7257
7258
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 7241

class PortalSummary < Struct.new(
  :authorization,
  :endpoint_configuration,
  :included_portal_product_arns,
  :last_modified,
  :last_published,
  :last_published_description,
  :portal_arn,
  :portal_content,
  :portal_id,
  :preview,
  :publish_status,
  :rum_app_monitor_name,
  :status_exception,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#last_modifiedTime

The timestamp when the portal was last modified.

Returns:



7241
7242
7243
7244
7245
7246
7247
7248
7249
7250
7251
7252
7253
7254
7255
7256
7257
7258
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 7241

class PortalSummary < Struct.new(
  :authorization,
  :endpoint_configuration,
  :included_portal_product_arns,
  :last_modified,
  :last_published,
  :last_published_description,
  :portal_arn,
  :portal_content,
  :portal_id,
  :preview,
  :publish_status,
  :rum_app_monitor_name,
  :status_exception,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#last_publishedTime

The timestamp when the portal was last published.

Returns:



7241
7242
7243
7244
7245
7246
7247
7248
7249
7250
7251
7252
7253
7254
7255
7256
7257
7258
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 7241

class PortalSummary < Struct.new(
  :authorization,
  :endpoint_configuration,
  :included_portal_product_arns,
  :last_modified,
  :last_published,
  :last_published_description,
  :portal_arn,
  :portal_content,
  :portal_id,
  :preview,
  :publish_status,
  :rum_app_monitor_name,
  :status_exception,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#last_published_descriptionString

The description of the portal the last time it was published.

Returns:



7241
7242
7243
7244
7245
7246
7247
7248
7249
7250
7251
7252
7253
7254
7255
7256
7257
7258
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 7241

class PortalSummary < Struct.new(
  :authorization,
  :endpoint_configuration,
  :included_portal_product_arns,
  :last_modified,
  :last_published,
  :last_published_description,
  :portal_arn,
  :portal_content,
  :portal_id,
  :preview,
  :publish_status,
  :rum_app_monitor_name,
  :status_exception,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#portal_arnString

The ARN of the portal.

Returns:



7241
7242
7243
7244
7245
7246
7247
7248
7249
7250
7251
7252
7253
7254
7255
7256
7257
7258
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 7241

class PortalSummary < Struct.new(
  :authorization,
  :endpoint_configuration,
  :included_portal_product_arns,
  :last_modified,
  :last_published,
  :last_published_description,
  :portal_arn,
  :portal_content,
  :portal_id,
  :preview,
  :publish_status,
  :rum_app_monitor_name,
  :status_exception,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#portal_contentTypes::PortalContent

Contains the content that is visible to portal consumers including the themes, display names, and description.

Returns:



7241
7242
7243
7244
7245
7246
7247
7248
7249
7250
7251
7252
7253
7254
7255
7256
7257
7258
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 7241

class PortalSummary < Struct.new(
  :authorization,
  :endpoint_configuration,
  :included_portal_product_arns,
  :last_modified,
  :last_published,
  :last_published_description,
  :portal_arn,
  :portal_content,
  :portal_id,
  :preview,
  :publish_status,
  :rum_app_monitor_name,
  :status_exception,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#portal_idString

The portal identifier.

Returns:



7241
7242
7243
7244
7245
7246
7247
7248
7249
7250
7251
7252
7253
7254
7255
7256
7257
7258
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 7241

class PortalSummary < Struct.new(
  :authorization,
  :endpoint_configuration,
  :included_portal_product_arns,
  :last_modified,
  :last_published,
  :last_published_description,
  :portal_arn,
  :portal_content,
  :portal_id,
  :preview,
  :publish_status,
  :rum_app_monitor_name,
  :status_exception,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#previewTypes::Preview

Represents the preview endpoint and the any possible error messages during preview generation.

Returns:



7241
7242
7243
7244
7245
7246
7247
7248
7249
7250
7251
7252
7253
7254
7255
7256
7257
7258
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 7241

class PortalSummary < Struct.new(
  :authorization,
  :endpoint_configuration,
  :included_portal_product_arns,
  :last_modified,
  :last_published,
  :last_published_description,
  :portal_arn,
  :portal_content,
  :portal_id,
  :preview,
  :publish_status,
  :rum_app_monitor_name,
  :status_exception,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#publish_statusString

The publish status.

Returns:



7241
7242
7243
7244
7245
7246
7247
7248
7249
7250
7251
7252
7253
7254
7255
7256
7257
7258
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 7241

class PortalSummary < Struct.new(
  :authorization,
  :endpoint_configuration,
  :included_portal_product_arns,
  :last_modified,
  :last_published,
  :last_published_description,
  :portal_arn,
  :portal_content,
  :portal_id,
  :preview,
  :publish_status,
  :rum_app_monitor_name,
  :status_exception,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#rum_app_monitor_nameString

The CloudWatch RUM app monitor name.

Returns:



7241
7242
7243
7244
7245
7246
7247
7248
7249
7250
7251
7252
7253
7254
7255
7256
7257
7258
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 7241

class PortalSummary < Struct.new(
  :authorization,
  :endpoint_configuration,
  :included_portal_product_arns,
  :last_modified,
  :last_published,
  :last_published_description,
  :portal_arn,
  :portal_content,
  :portal_id,
  :preview,
  :publish_status,
  :rum_app_monitor_name,
  :status_exception,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#status_exceptionTypes::StatusException

The status exception information.

Returns:



7241
7242
7243
7244
7245
7246
7247
7248
7249
7250
7251
7252
7253
7254
7255
7256
7257
7258
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 7241

class PortalSummary < Struct.new(
  :authorization,
  :endpoint_configuration,
  :included_portal_product_arns,
  :last_modified,
  :last_published,
  :last_published_description,
  :portal_arn,
  :portal_content,
  :portal_id,
  :preview,
  :publish_status,
  :rum_app_monitor_name,
  :status_exception,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The collection of tags. Each tag element is associated with a given resource.

Returns:



7241
7242
7243
7244
7245
7246
7247
7248
7249
7250
7251
7252
7253
7254
7255
7256
7257
7258
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 7241

class PortalSummary < Struct.new(
  :authorization,
  :endpoint_configuration,
  :included_portal_product_arns,
  :last_modified,
  :last_published,
  :last_published_description,
  :portal_arn,
  :portal_content,
  :portal_id,
  :preview,
  :publish_status,
  :rum_app_monitor_name,
  :status_exception,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end