Class: Aws::ApiGatewayV2::Types::UpdateProductRestEndpointPageResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApiGatewayV2::Types::UpdateProductRestEndpointPageResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-apigatewayv2/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#display_content ⇒ Types::EndpointDisplayContentResponse
The product REST endpoint page.
- #last_modified ⇒ Time
- #product_rest_endpoint_page_arn ⇒ String
- #product_rest_endpoint_page_id ⇒ String
-
#rest_endpoint_identifier ⇒ Types::RestEndpointIdentifier
The REST API endpoint identifier.
-
#status ⇒ String
The status.
-
#status_exception ⇒ Types::StatusException
Represents a StatusException.
-
#try_it_state ⇒ String
Represents the try it state for a product REST endpoint page.
Instance Attribute Details
#display_content ⇒ Types::EndpointDisplayContentResponse
The product REST endpoint page.
10441 10442 10443 10444 10445 10446 10447 10448 10449 10450 10451 10452 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 10441 class UpdateProductRestEndpointPageResponse < Struct.new( :display_content, :last_modified, :product_rest_endpoint_page_arn, :product_rest_endpoint_page_id, :rest_endpoint_identifier, :status, :status_exception, :try_it_state) SENSITIVE = [] include Aws::Structure end |
#last_modified ⇒ Time
10441 10442 10443 10444 10445 10446 10447 10448 10449 10450 10451 10452 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 10441 class UpdateProductRestEndpointPageResponse < Struct.new( :display_content, :last_modified, :product_rest_endpoint_page_arn, :product_rest_endpoint_page_id, :rest_endpoint_identifier, :status, :status_exception, :try_it_state) SENSITIVE = [] include Aws::Structure end |
#product_rest_endpoint_page_arn ⇒ String
10441 10442 10443 10444 10445 10446 10447 10448 10449 10450 10451 10452 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 10441 class UpdateProductRestEndpointPageResponse < Struct.new( :display_content, :last_modified, :product_rest_endpoint_page_arn, :product_rest_endpoint_page_id, :rest_endpoint_identifier, :status, :status_exception, :try_it_state) SENSITIVE = [] include Aws::Structure end |
#product_rest_endpoint_page_id ⇒ String
10441 10442 10443 10444 10445 10446 10447 10448 10449 10450 10451 10452 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 10441 class UpdateProductRestEndpointPageResponse < Struct.new( :display_content, :last_modified, :product_rest_endpoint_page_arn, :product_rest_endpoint_page_id, :rest_endpoint_identifier, :status, :status_exception, :try_it_state) SENSITIVE = [] include Aws::Structure end |
#rest_endpoint_identifier ⇒ Types::RestEndpointIdentifier
The REST API endpoint identifier.
10441 10442 10443 10444 10445 10446 10447 10448 10449 10450 10451 10452 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 10441 class UpdateProductRestEndpointPageResponse < Struct.new( :display_content, :last_modified, :product_rest_endpoint_page_arn, :product_rest_endpoint_page_id, :rest_endpoint_identifier, :status, :status_exception, :try_it_state) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status.
10441 10442 10443 10444 10445 10446 10447 10448 10449 10450 10451 10452 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 10441 class UpdateProductRestEndpointPageResponse < Struct.new( :display_content, :last_modified, :product_rest_endpoint_page_arn, :product_rest_endpoint_page_id, :rest_endpoint_identifier, :status, :status_exception, :try_it_state) SENSITIVE = [] include Aws::Structure end |
#status_exception ⇒ Types::StatusException
Represents a StatusException.
10441 10442 10443 10444 10445 10446 10447 10448 10449 10450 10451 10452 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 10441 class UpdateProductRestEndpointPageResponse < Struct.new( :display_content, :last_modified, :product_rest_endpoint_page_arn, :product_rest_endpoint_page_id, :rest_endpoint_identifier, :status, :status_exception, :try_it_state) SENSITIVE = [] include Aws::Structure end |
#try_it_state ⇒ String
Represents the try it state for a product REST endpoint page.
10441 10442 10443 10444 10445 10446 10447 10448 10449 10450 10451 10452 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 10441 class UpdateProductRestEndpointPageResponse < Struct.new( :display_content, :last_modified, :product_rest_endpoint_page_arn, :product_rest_endpoint_page_id, :rest_endpoint_identifier, :status, :status_exception, :try_it_state) SENSITIVE = [] include Aws::Structure end |