Class: Aws::ApiGatewayV2::Types::CreatePortalRequestContent
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApiGatewayV2::Types::CreatePortalRequestContent
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-apigatewayv2/types.rb
Overview
Creates a portal.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#authorization ⇒ Types::Authorization
The authentication configuration for the portal.
-
#endpoint_configuration ⇒ Types::EndpointConfigurationRequest
The domain configuration for the portal.
-
#included_portal_product_arns ⇒ Array<String>
The ARNs of the portal products included in the portal.
-
#logo_uri ⇒ String
The URI for the portal logo image that is displayed in the portal header.
-
#portal_content ⇒ Types::PortalContent
The content of the portal.
-
#rum_app_monitor_name ⇒ String
The name of the Amazon CloudWatch RUM app monitor for the portal.
-
#tags ⇒ Hash<String,String>
The collection of tags.
Instance Attribute Details
#authorization ⇒ Types::Authorization
The authentication configuration for the portal.
2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 2404 class CreatePortalRequestContent < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :logo_uri, :portal_content, :rum_app_monitor_name, :tags) SENSITIVE = [] include Aws::Structure end |
#endpoint_configuration ⇒ Types::EndpointConfigurationRequest
The domain configuration for the portal. Use a default domain provided by API Gateway or provide a fully-qualified domain name that you own.
2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 2404 class CreatePortalRequestContent < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :logo_uri, :portal_content, :rum_app_monitor_name, :tags) SENSITIVE = [] include Aws::Structure end |
#included_portal_product_arns ⇒ Array<String>
The ARNs of the portal products included in the portal.
2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 2404 class CreatePortalRequestContent < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :logo_uri, :portal_content, :rum_app_monitor_name, :tags) SENSITIVE = [] include Aws::Structure end |
#logo_uri ⇒ String
The URI for the portal logo image that is displayed in the portal header.
2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 2404 class CreatePortalRequestContent < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :logo_uri, :portal_content, :rum_app_monitor_name, :tags) SENSITIVE = [] include Aws::Structure end |
#portal_content ⇒ Types::PortalContent
The content of the portal.
2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 2404 class CreatePortalRequestContent < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :logo_uri, :portal_content, :rum_app_monitor_name, :tags) SENSITIVE = [] include Aws::Structure end |
#rum_app_monitor_name ⇒ String
The name of the Amazon CloudWatch RUM app monitor for the portal.
2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 2404 class CreatePortalRequestContent < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :logo_uri, :portal_content, :rum_app_monitor_name, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The collection of tags. Each tag element is associated with a given resource.
2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 2404 class CreatePortalRequestContent < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :logo_uri, :portal_content, :rum_app_monitor_name, :tags) SENSITIVE = [] include Aws::Structure end |