Class: Aws::ApiGatewayV2::Types::GetPortalResponseContent
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApiGatewayV2::Types::GetPortalResponseContent
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-apigatewayv2/types.rb
Overview
Gets a portal.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#authorization ⇒ Types::Authorization
The authorization for the portal.
-
#endpoint_configuration ⇒ Types::EndpointConfigurationResponse
The endpoint configuration.
-
#included_portal_product_arns ⇒ Array<String>
The ARNs of the portal products included in the portal.
-
#last_modified ⇒ Time
The timestamp when the portal was last modified.
-
#last_published ⇒ Time
The timestamp when the portal was last published.
-
#last_published_description ⇒ String
The publish description used when the portal was last published.
-
#portal_arn ⇒ String
The ARN of the portal.
-
#portal_content ⇒ Types::PortalContent
Contains the content that is visible to portal consumers including the themes, display names, and description.
-
#portal_id ⇒ String
The portal identifier.
-
#preview ⇒ Types::Preview
Represents the preview endpoint and the any possible error messages during preview generation.
-
#publish_status ⇒ String
The publish status of a portal.
-
#rum_app_monitor_name ⇒ String
The CloudWatch RUM app monitor name.
-
#status_exception ⇒ Types::StatusException
The status exception information.
-
#tags ⇒ Hash<String,String>
The collection of tags.
Instance Attribute Details
#authorization ⇒ Types::Authorization
The authorization for the portal.
5420 5421 5422 5423 5424 5425 5426 5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 5420 class GetPortalResponseContent < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :last_modified, :last_published, :last_published_description, :portal_arn, :portal_content, :portal_id, :preview, :publish_status, :rum_app_monitor_name, :status_exception, :tags) SENSITIVE = [] include Aws::Structure end |
#endpoint_configuration ⇒ Types::EndpointConfigurationResponse
The endpoint configuration.
5420 5421 5422 5423 5424 5425 5426 5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 5420 class GetPortalResponseContent < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :last_modified, :last_published, :last_published_description, :portal_arn, :portal_content, :portal_id, :preview, :publish_status, :rum_app_monitor_name, :status_exception, :tags) SENSITIVE = [] include Aws::Structure end |
#included_portal_product_arns ⇒ Array<String>
The ARNs of the portal products included in the portal.
5420 5421 5422 5423 5424 5425 5426 5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 5420 class GetPortalResponseContent < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :last_modified, :last_published, :last_published_description, :portal_arn, :portal_content, :portal_id, :preview, :publish_status, :rum_app_monitor_name, :status_exception, :tags) SENSITIVE = [] include Aws::Structure end |
#last_modified ⇒ Time
The timestamp when the portal was last modified.
5420 5421 5422 5423 5424 5425 5426 5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 5420 class GetPortalResponseContent < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :last_modified, :last_published, :last_published_description, :portal_arn, :portal_content, :portal_id, :preview, :publish_status, :rum_app_monitor_name, :status_exception, :tags) SENSITIVE = [] include Aws::Structure end |
#last_published ⇒ Time
The timestamp when the portal was last published.
5420 5421 5422 5423 5424 5425 5426 5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 5420 class GetPortalResponseContent < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :last_modified, :last_published, :last_published_description, :portal_arn, :portal_content, :portal_id, :preview, :publish_status, :rum_app_monitor_name, :status_exception, :tags) SENSITIVE = [] include Aws::Structure end |
#last_published_description ⇒ String
The publish description used when the portal was last published.
5420 5421 5422 5423 5424 5425 5426 5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 5420 class GetPortalResponseContent < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :last_modified, :last_published, :last_published_description, :portal_arn, :portal_content, :portal_id, :preview, :publish_status, :rum_app_monitor_name, :status_exception, :tags) SENSITIVE = [] include Aws::Structure end |
#portal_arn ⇒ String
The ARN of the portal.
5420 5421 5422 5423 5424 5425 5426 5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 5420 class GetPortalResponseContent < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :last_modified, :last_published, :last_published_description, :portal_arn, :portal_content, :portal_id, :preview, :publish_status, :rum_app_monitor_name, :status_exception, :tags) SENSITIVE = [] include Aws::Structure end |
#portal_content ⇒ Types::PortalContent
Contains the content that is visible to portal consumers including the themes, display names, and description.
5420 5421 5422 5423 5424 5425 5426 5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 5420 class GetPortalResponseContent < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :last_modified, :last_published, :last_published_description, :portal_arn, :portal_content, :portal_id, :preview, :publish_status, :rum_app_monitor_name, :status_exception, :tags) SENSITIVE = [] include Aws::Structure end |
#portal_id ⇒ String
The portal identifier.
5420 5421 5422 5423 5424 5425 5426 5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 5420 class GetPortalResponseContent < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :last_modified, :last_published, :last_published_description, :portal_arn, :portal_content, :portal_id, :preview, :publish_status, :rum_app_monitor_name, :status_exception, :tags) SENSITIVE = [] include Aws::Structure end |
#preview ⇒ Types::Preview
Represents the preview endpoint and the any possible error messages during preview generation.
5420 5421 5422 5423 5424 5425 5426 5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 5420 class GetPortalResponseContent < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :last_modified, :last_published, :last_published_description, :portal_arn, :portal_content, :portal_id, :preview, :publish_status, :rum_app_monitor_name, :status_exception, :tags) SENSITIVE = [] include Aws::Structure end |
#publish_status ⇒ String
The publish status of a portal.
5420 5421 5422 5423 5424 5425 5426 5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 5420 class GetPortalResponseContent < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :last_modified, :last_published, :last_published_description, :portal_arn, :portal_content, :portal_id, :preview, :publish_status, :rum_app_monitor_name, :status_exception, :tags) SENSITIVE = [] include Aws::Structure end |
#rum_app_monitor_name ⇒ String
The CloudWatch RUM app monitor name.
5420 5421 5422 5423 5424 5425 5426 5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 5420 class GetPortalResponseContent < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :last_modified, :last_published, :last_published_description, :portal_arn, :portal_content, :portal_id, :preview, :publish_status, :rum_app_monitor_name, :status_exception, :tags) SENSITIVE = [] include Aws::Structure end |
#status_exception ⇒ Types::StatusException
The status exception information.
5420 5421 5422 5423 5424 5425 5426 5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 5420 class GetPortalResponseContent < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :last_modified, :last_published, :last_published_description, :portal_arn, :portal_content, :portal_id, :preview, :publish_status, :rum_app_monitor_name, :status_exception, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The collection of tags. Each tag element is associated with a given resource.
5420 5421 5422 5423 5424 5425 5426 5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 5420 class GetPortalResponseContent < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :last_modified, :last_published, :last_published_description, :portal_arn, :portal_content, :portal_id, :preview, :publish_status, :rum_app_monitor_name, :status_exception, :tags) SENSITIVE = [] include Aws::Structure end |