Class: Aws::ApiGatewayV2::Types::PortalSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApiGatewayV2::Types::PortalSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-apigatewayv2/types.rb
Overview
Represents a portal summary.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#authorization ⇒ Types::Authorization
The authorization of the portal.
-
#endpoint_configuration ⇒ Types::EndpointConfigurationResponse
The endpoint configuration of the portal.
-
#included_portal_product_arns ⇒ Array<String>
The ARNs of the portal products included in the portal.
-
#last_modified ⇒ Time
The timestamp when the portal was last modified.
-
#last_published ⇒ Time
The timestamp when the portal was last published.
-
#last_published_description ⇒ String
The description of the portal the last time it was published.
-
#portal_arn ⇒ String
The ARN of the portal.
-
#portal_content ⇒ Types::PortalContent
Contains the content that is visible to portal consumers including the themes, display names, and description.
-
#portal_id ⇒ String
The portal identifier.
-
#preview ⇒ Types::Preview
Represents the preview endpoint and the any possible error messages during preview generation.
-
#publish_status ⇒ String
The publish status.
-
#rum_app_monitor_name ⇒ String
The CloudWatch RUM app monitor name.
-
#status_exception ⇒ Types::StatusException
The status exception information.
-
#tags ⇒ Hash<String,String>
The collection of tags.
Instance Attribute Details
#authorization ⇒ Types::Authorization
The authorization of the portal.
7241 7242 7243 7244 7245 7246 7247 7248 7249 7250 7251 7252 7253 7254 7255 7256 7257 7258 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 7241 class PortalSummary < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :last_modified, :last_published, :last_published_description, :portal_arn, :portal_content, :portal_id, :preview, :publish_status, :rum_app_monitor_name, :status_exception, :tags) SENSITIVE = [] include Aws::Structure end |
#endpoint_configuration ⇒ Types::EndpointConfigurationResponse
The endpoint configuration of the portal.
7241 7242 7243 7244 7245 7246 7247 7248 7249 7250 7251 7252 7253 7254 7255 7256 7257 7258 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 7241 class PortalSummary < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :last_modified, :last_published, :last_published_description, :portal_arn, :portal_content, :portal_id, :preview, :publish_status, :rum_app_monitor_name, :status_exception, :tags) SENSITIVE = [] include Aws::Structure end |
#included_portal_product_arns ⇒ Array<String>
The ARNs of the portal products included in the portal.
7241 7242 7243 7244 7245 7246 7247 7248 7249 7250 7251 7252 7253 7254 7255 7256 7257 7258 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 7241 class PortalSummary < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :last_modified, :last_published, :last_published_description, :portal_arn, :portal_content, :portal_id, :preview, :publish_status, :rum_app_monitor_name, :status_exception, :tags) SENSITIVE = [] include Aws::Structure end |
#last_modified ⇒ Time
The timestamp when the portal was last modified.
7241 7242 7243 7244 7245 7246 7247 7248 7249 7250 7251 7252 7253 7254 7255 7256 7257 7258 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 7241 class PortalSummary < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :last_modified, :last_published, :last_published_description, :portal_arn, :portal_content, :portal_id, :preview, :publish_status, :rum_app_monitor_name, :status_exception, :tags) SENSITIVE = [] include Aws::Structure end |
#last_published ⇒ Time
The timestamp when the portal was last published.
7241 7242 7243 7244 7245 7246 7247 7248 7249 7250 7251 7252 7253 7254 7255 7256 7257 7258 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 7241 class PortalSummary < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :last_modified, :last_published, :last_published_description, :portal_arn, :portal_content, :portal_id, :preview, :publish_status, :rum_app_monitor_name, :status_exception, :tags) SENSITIVE = [] include Aws::Structure end |
#last_published_description ⇒ String
The description of the portal the last time it was published.
7241 7242 7243 7244 7245 7246 7247 7248 7249 7250 7251 7252 7253 7254 7255 7256 7257 7258 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 7241 class PortalSummary < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :last_modified, :last_published, :last_published_description, :portal_arn, :portal_content, :portal_id, :preview, :publish_status, :rum_app_monitor_name, :status_exception, :tags) SENSITIVE = [] include Aws::Structure end |
#portal_arn ⇒ String
The ARN of the portal.
7241 7242 7243 7244 7245 7246 7247 7248 7249 7250 7251 7252 7253 7254 7255 7256 7257 7258 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 7241 class PortalSummary < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :last_modified, :last_published, :last_published_description, :portal_arn, :portal_content, :portal_id, :preview, :publish_status, :rum_app_monitor_name, :status_exception, :tags) SENSITIVE = [] include Aws::Structure end |
#portal_content ⇒ Types::PortalContent
Contains the content that is visible to portal consumers including the themes, display names, and description.
7241 7242 7243 7244 7245 7246 7247 7248 7249 7250 7251 7252 7253 7254 7255 7256 7257 7258 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 7241 class PortalSummary < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :last_modified, :last_published, :last_published_description, :portal_arn, :portal_content, :portal_id, :preview, :publish_status, :rum_app_monitor_name, :status_exception, :tags) SENSITIVE = [] include Aws::Structure end |
#portal_id ⇒ String
The portal identifier.
7241 7242 7243 7244 7245 7246 7247 7248 7249 7250 7251 7252 7253 7254 7255 7256 7257 7258 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 7241 class PortalSummary < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :last_modified, :last_published, :last_published_description, :portal_arn, :portal_content, :portal_id, :preview, :publish_status, :rum_app_monitor_name, :status_exception, :tags) SENSITIVE = [] include Aws::Structure end |
#preview ⇒ Types::Preview
Represents the preview endpoint and the any possible error messages during preview generation.
7241 7242 7243 7244 7245 7246 7247 7248 7249 7250 7251 7252 7253 7254 7255 7256 7257 7258 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 7241 class PortalSummary < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :last_modified, :last_published, :last_published_description, :portal_arn, :portal_content, :portal_id, :preview, :publish_status, :rum_app_monitor_name, :status_exception, :tags) SENSITIVE = [] include Aws::Structure end |
#publish_status ⇒ String
The publish status.
7241 7242 7243 7244 7245 7246 7247 7248 7249 7250 7251 7252 7253 7254 7255 7256 7257 7258 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 7241 class PortalSummary < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :last_modified, :last_published, :last_published_description, :portal_arn, :portal_content, :portal_id, :preview, :publish_status, :rum_app_monitor_name, :status_exception, :tags) SENSITIVE = [] include Aws::Structure end |
#rum_app_monitor_name ⇒ String
The CloudWatch RUM app monitor name.
7241 7242 7243 7244 7245 7246 7247 7248 7249 7250 7251 7252 7253 7254 7255 7256 7257 7258 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 7241 class PortalSummary < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :last_modified, :last_published, :last_published_description, :portal_arn, :portal_content, :portal_id, :preview, :publish_status, :rum_app_monitor_name, :status_exception, :tags) SENSITIVE = [] include Aws::Structure end |
#status_exception ⇒ Types::StatusException
The status exception information.
7241 7242 7243 7244 7245 7246 7247 7248 7249 7250 7251 7252 7253 7254 7255 7256 7257 7258 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 7241 class PortalSummary < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :last_modified, :last_published, :last_published_description, :portal_arn, :portal_content, :portal_id, :preview, :publish_status, :rum_app_monitor_name, :status_exception, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The collection of tags. Each tag element is associated with a given resource.
7241 7242 7243 7244 7245 7246 7247 7248 7249 7250 7251 7252 7253 7254 7255 7256 7257 7258 |
# File 'lib/aws-sdk-apigatewayv2/types.rb', line 7241 class PortalSummary < Struct.new( :authorization, :endpoint_configuration, :included_portal_product_arns, :last_modified, :last_published, :last_published_description, :portal_arn, :portal_content, :portal_id, :preview, :publish_status, :rum_app_monitor_name, :status_exception, :tags) SENSITIVE = [] include Aws::Structure end |